smartcard.Exceptions.SmartcardException

# ``smartcard`.`Exceptions`.`SmartcardException``

exception documentation

`class SmartcardException(Exception):`

Known subclasses: `smartcard.Exceptions.CardConnectionException`, `smartcard.Exceptions.CardRequestException`, `smartcard.Exceptions.CardRequestTimeoutException`, `smartcard.Exceptions.CardServiceException`, `smartcard.Exceptions.CardServiceStoppedException`, `smartcard.Exceptions.InvalidATRMaskLengthException`, `smartcard.Exceptions.InvalidReaderException`, `smartcard.Exceptions.ListReadersException`, `smartcard.Exceptions.NoCardException`, `smartcard.Exceptions.NoReadersException`, `smartcard.reader.ReaderGroups.BadReaderGroupException`, `smartcard.reader.ReaderGroups.DeleteSCardDefaultReaderGroupException`

View In Hierarchy

Base class for smartcard exceptions.

smartcard exceptions are generated by the smartcard module and shield scard (i.e. PCSC) exceptions raised by the scard module.

Method | `__init__` | Undocumented
Method | `__str__` | Undocumented
Instance Variable | `hresult` | Undocumented

def __init__(self, message='', hresult=-1, *args):
overridden in `smartcard.Exceptions.CardRequestTimeoutException`, `smartcard.Exceptions.InvalidATRMaskLengthException`, `smartcard.Exceptions.InvalidReaderException`, `smartcard.Exceptions.ListReadersException`, `smartcard.Exceptions.NoCardException`, `smartcard.Exceptions.NoReadersException`, `smartcard.reader.ReaderGroups.BadReaderGroupException`, `smartcard.reader.ReaderGroups.DeleteSCardDefaultReaderGroupException`

Undocumented

def __str__(self):

Undocumented

hresult =

Undocumented